# Caikit Architecture Club

Standing meetings for maintainers to discuss larger design issues moving forward

## Potential Topics

- module backends and startup semantics
- how do we handle metering
- ~~configuration~~
- what do we do about the current `workflow` module type

## Meetings

[April 25th 2023](04-25-23.md) Topic: Configuration
